==============================================================
Introduction to poets, the Python Open Earth Observation Tools
==============================================================
.. image:: https://badge.fury.io/py/poets.svg
    :target: http://badge.fury.io/py/poets

poets is a package with aims to provide a standard library that can be used for
collecting and resampling geospatial image datasets.

Features
========

* easy download of geospatial image datasets
* spatial and temporal resampling of datasets
* storing resampled images in "datacube-like"-NetCDF4 file
* web interface for displaying images and time series in a browser

Documentation
=============

Please see the latest documentation including examples of how to install and use poets at http://geo.tuwien.ac.at/poets